@@ -406,6 +406,12 @@ package org.opencv.core;
  * any STL algorithm, including <code>std.sort()</code>.
  * </code></p>
  *
+ * <p>Note:</p>
+ * <ul>
+ *   <li> An example demonstrating the serial out capabilities of cv.Mat can be
+ * found at opencv_source_code/samples/cpp/cout_mat.cpp
+ * </ul>
+ *
  * @see <a href="http://docs.opencv.org/modules/core/doc/basic_structures.html#mat">org.opencv.core.Mat</a>
  */
 public class Mat {
@@ -461,7 +467,7 @@ public class Mat {
  * @param cols Number of columns in a 2D array.
  * @param type Array type. Use <code>CV_8UC1,..., CV_64FC4</code> to create 1-4
  * channel matrices, or <code>CV_8UC(n),..., CV_64FC(n)</code> to create
- * multi-channel (up to <code>CV_MAX_CN</code> channels) matrices.
+ * multi-channel (up to <code>CV_CN_MAX</code> channels) matrices.
  *
  * @see <a href="http://docs.opencv.org/modules/core/doc/basic_structures.html#mat-mat">org.opencv.core.Mat.Mat</a>
  */
@@ -492,7 +498,7 @@ public class Mat {
  * go in the reverse order.
  * @param type Array type. Use <code>CV_8UC1,..., CV_64FC4</code> to create 1-4
  * channel matrices, or <code>CV_8UC(n),..., CV_64FC(n)</code> to create
- * multi-channel (up to <code>CV_MAX_CN</code> channels) matrices.
+ * multi-channel (up to <code>CV_CN_MAX</code> channels) matrices.
  *
  * @see <a href="http://docs.opencv.org/modules/core/doc/basic_structures.html#mat-mat">org.opencv.core.Mat.Mat</a>
  */
@@ -522,7 +528,7 @@ public class Mat {
  * @param cols Number of columns in a 2D array.
  * @param type Array type. Use <code>CV_8UC1,..., CV_64FC4</code> to create 1-4
  * channel matrices, or <code>CV_8UC(n),..., CV_64FC(n)</code> to create
- * multi-channel (up to <code>CV_MAX_CN</code> channels) matrices.
+ * multi-channel (up to <code>CV_CN_MAX</code> channels) matrices.
  * @param s An optional value to initialize each matrix element with. To set all
  * the matrix elements to the particular value after the construction, use the
  * assignment operator <code>Mat.operator=(const Scalar& value)</code>.
@@ -556,7 +562,7 @@ public class Mat {
  * go in the reverse order.
  * @param type Array type. Use <code>CV_8UC1,..., CV_64FC4</code> to create 1-4
  * channel matrices, or <code>CV_8UC(n),..., CV_64FC(n)</code> to create
- * multi-channel (up to <code>CV_MAX_CN</code> channels) matrices.
+ * multi-channel (up to <code>CV_CN_MAX</code> channels) matrices.
  * @param s An optional value to initialize each matrix element with. To set all
  * the matrix elements to the particular value after the construction, use the
  * assignment operator <code>Mat.operator=(const Scalar& value)</code>.
@@ -859,7 +865,7 @@ public class Mat {
     //
 
 /**
- * <p>Creates a matrix header for the specified row span.</p>
+ * <p>Creates a matrix header for the specified column span.</p>
  *
  * <p>The method makes a new header for the specified column span of the matrix.
  * Similarly to "Mat.row" and "Mat.col", this is an O(1) operation.</p>
@@ -882,7 +888,7 @@ public class Mat {
     //
 
 /**
- * <p>Creates a matrix header for the specified row span.</p>
+ * <p>Creates a matrix header for the specified column span.</p>
  *
  * <p>The method makes a new header for the specified column span of the matrix.
  * Similarly to "Mat.row" and "Mat.col", this is an O(1) operation.</p>
@@ -899,6 +905,18 @@ public class Mat {
         return retVal;
     }
 
+    //
+    // C++: int Mat::dims()
+    //
+
+    public int dims()
+    {
+
+        int retVal = n_dims(nativeObj);
+
+        return retVal;
+    }
+
     //
     // C++: int Mat::cols()
     //
@@ -1006,15 +1024,15 @@ public class Mat {
  *
  * <p>// C++ code:</p>
  *
- * <p>m.create(this->size(), this->type);</p>
+ * <p>m.create(this->size(), this->type());</p>
  *
  * <p>so that the destination matrix is reallocated if needed. While
  * <code>m.copyTo(m);</code> works flawlessly, the function does not handle the
  * case of a partial overlap between the source and the destination matrices.
  * </code></p>
  *
- * <p>When the operation mask is specified, and the <code>Mat.create</code> call
- * shown above reallocated the matrix, the newly allocated matrix is initialized
+ * <p>When the operation mask is specified, if the <code>Mat.create</code> call
+ * shown above reallocates the matrix, the newly allocated matrix is initialized
  * with all zeros before copying the data.</p>
  *
  * @param m Destination matrix. If it does not have a proper size or type before
@@ -1042,21 +1060,22 @@ public class Mat {
  *
  * <p>// C++ code:</p>
  *
- * <p>m.create(this->size(), this->type);</p>
+ * <p>m.create(this->size(), this->type());</p>
  *
  * <p>so that the destination matrix is reallocated if needed. While
  * <code>m.copyTo(m);</code> works flawlessly, the function does not handle the
  * case of a partial overlap between the source and the destination matrices.
  * </code></p>
  *
- * <p>When the operation mask is specified, and the <code>Mat.create</code> call
- * shown above reallocated the matrix, the newly allocated matrix is initialized
+ * <p>When the operation mask is specified, if the <code>Mat.create</code> call
+ * shown above reallocates the matrix, the newly allocated matrix is initialized
  * with all zeros before copying the data.</p>
  *
  * @param m Destination matrix. If it does not have a proper size or type before
  * the operation, it is reallocated.
  * @param mask Operation mask. Its non-zero elements indicate which matrix
- * elements need to be copied.
+ * elements need to be copied. Keep in mind that the mask needs to be of type
+ * CV_8U and can have 1 or multiple channels.
  *
  * @see <a href="http://docs.opencv.org/modules/core/doc/basic_structures.html#mat-copyto">org.opencv.core.Mat.copyTo</a>
  */
@@ -2323,7 +2342,7 @@ public class Mat {
  *
  * <p>// C++ code:</p>
  *
- * <p>Mat A1 = A + Mat.eye(A.size(), A.type)*lambda;</p>
+ * <p>Mat A1 = A + Mat.eye(A.size(), A.type())*lambda;</p>
  *
  * <p>Mat C = A1.t()*A1; // compute (A + lambda*I)^t * (A + lamda*I)</p>
  *
@@ -2673,6 +2692,9 @@ public class Mat {
     // C++: Mat Mat::colRange(int startcol, int endcol)
     private static native long n_colRange(long nativeObj, int startcol, int endcol);
 
+    // C++: int Mat::dims()
+    private static native int n_dims(long nativeObj);
+
     // C++: int Mat::cols()
     private static native int n_cols(long nativeObj);
 
